==> haskell-hls-class-plugin-2.0.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-class-plugin-2.0.0.0-C59ZdnzToo06ZW1bQ5GCl5
key:                  hls-class-plugin-2.0.0.0-C59ZdnzToo06ZW1bQ5GCl5
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5113ce71371f75141b99a240989548ab
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.0.0.0-C59ZdnzToo06ZW1bQ5GCl5
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-1pC2UooR1UK8f5nfgopCxy
    ghcide-2.0.0.0-DRI4NY9c6PIkGk9WaJTQj
    hls-graph-2.0.0.0-60x3ybMrD4x7nBwBcJteyH
    hls-plugin-api-2.0.0.0-I7YEHyKncWN58S7zoavJND
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1 lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-class-plugin-2.0.0.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-class-plugin-2.0.0.0-5rwR4q9Is926NSrNSJ5HVT
key:                  hls-class-plugin-2.0.0.0-5rwR4q9Is926NSrNSJ5HVT
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cc26593ea9504fcbf077b76997084940
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.0.0.0-5rwR4q9Is926NSrNSJ5HVT
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-1pC2UooR1UK8f5nfgopCxy
    ghcide-2.0.0.0-1UXOBe0HT3ICfnA7ApAAfD
    hls-graph-2.0.0.0-JYeeHmgNg2DDktsEgZBp9J
    hls-plugin-api-2.0.0.0-L5enBKJhMYCCSCAkShlHZC
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1 lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
